==> haskell-universe-reverse-instances-1.1.1-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-universe-reverse-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 universe-reverse-instances
version:              1.1.1
visibility:           public
id:                   universe-reverse-instances-1.1.1-I34mFLkSh8FAPlUBwIExb
key:                  universe-reverse-instances-1.1.1-I34mFLkSh8FAPlUBwIExb
license:              BSD-3-Clause
copyright:            Daniel Wagner 2014
maintainer:           me@dmwit.com
author:               Daniel Wagner
homepage:             https://github.com/dmwit/universe
synopsis:
    Instances of standard classes that are made possible by enumerations

description:
    For example this package provides a @Eq (a -> b)@ instance:

    @
    instance (Finite a, Eq b) => Eq (a -> b) where
    f == g = and [f x == g x | x <- universeF]
    @

category:             Data
abi:                  701fe52ad25b6837a0a8305a6fac5b9c
exposed:              True
exposed-modules:
    Data.Universe.Instances.Eq Data.Universe.Instances.Ord
    Data.Universe.Instances.Read Data.Universe.Instances.Show
    Data.Universe.Instances.Traversable

import-dirs:
    /usr/lib/ghc-9.0.1/site-local/universe-reverse-instances-1.1.1

library-dirs:
    /usr/lib/ghc-9.0.1/site-local/universe-reverse-instances-1.1.1

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/universe-reverse-instances-1.1.1

hs-libraries:         HSuniverse-reverse-instances-1.1.1-I34mFLkSh8FAPlUBwIExb
depends:
    base-4.15.0.0 containers-0.6.4.1
    universe-base-1.1.2-Kpax0UcxtcJGAPsueTX4zS

haddock-interfaces:
    /usr/share/doc/haskell-universe-reverse-instances/html/universe-reverse-instances.haddock

haddock-html:         /usr/share/doc/haskell-universe-reverse-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-universe-reverse-instances-1.1.1-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-universe-reverse-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 universe-reverse-instances
version:              1.1.1
visibility:           public
id:                   universe-reverse-instances-1.1.1-Jp0cs6Bwxol3aOmHdeXIh1
key:                  universe-reverse-instances-1.1.1-Jp0cs6Bwxol3aOmHdeXIh1
license:              BSD-3-Clause
copyright:            Daniel Wagner 2014
maintainer:           me@dmwit.com
author:               Daniel Wagner
homepage:             https://github.com/dmwit/universe
synopsis:
    Instances of standard classes that are made possible by enumerations

description:
    For example this package provides a @Eq (a -> b)@ instance:

    @
    instance (Finite a, Eq b) => Eq (a -> b) where
    f == g = and [f x == g x | x <- universeF]
    @

category:             Data
abi:                  bb54ffd8054a089c832bbe34d28cb1b2
exposed:              True
exposed-modules:
    Data.Universe.Instances.Eq Data.Universe.Instances.Ord
    Data.Universe.Instances.Read Data.Universe.Instances.Show
    Data.Universe.Instances.Traversable

import-dirs:
    /usr/lib/ghc-9.0.1/site-local/universe-reverse-instances-1.1.1

library-dirs:
    /usr/lib/ghc-9.0.1/site-local/universe-reverse-instances-1.1.1

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/universe-reverse-instances-1.1.1

hs-libraries:         HSuniverse-reverse-instances-1.1.1-Jp0cs6Bwxol3aOmHdeXIh1
depends:
    base-4.15.0.0 containers-0.6.4.1
    universe-base-1.1.2-Ik0WvII2Z3LDJq9Wf22lMe

haddock-interfaces:
    /usr/share/doc/haskell-universe-reverse-instances/html/universe-reverse-instances.haddock

haddock-html:         /usr/share/doc/haskell-universe-reverse-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
